@@ -7,7 +7,7 @@ Example: ::
     from webargs.bottleparser import use_args
 
     hello_args = {
-        'name': fields.Str(missing='World')
+        'name': fields.Str(load_default='World')
     }
     @route('/', method='GET', apply=use_args(hello_args))
     def index(args):
@@ -19,10 +19,9 @@ Example: ::
 import bottle
 
 from webargs import core
-from webargs.multidictproxy import MultiDictProxy
 
 
-class BottleParser(core.Parser):
+class BottleParser(core.Parser[bottle.Request]):
     """Bottle.py request argument parser."""
 
     def _handle_invalid_json_error(self, error, req, *args, **kwargs):
@@ -37,7 +36,7 @@ class BottleParser(core.Parser):
         except AttributeError:
             return core.missing
 
-        # unfortunately, bottle does not distinguish between an emtpy body, "",
+        # unfortunately, bottle does not distinguish between an empty body, "",
         # and a body containing the valid JSON value null, "null"
         # so these can't be properly disambiguated
         # as our best-effort solution, treat None as missing and ignore the
@@ -49,7 +48,7 @@ class BottleParser(core.Parser):
 
     def load_querystring(self, req, schema):
         """Return query params from the request as a MultiDictProxy."""
-        return MultiDictProxy(req.query, schema)
+        return self._makeproxy(req.query, schema)
 
     def load_form(self, req, schema):
         """Return form values from the request as a MultiDictProxy."""
@@ -58,11 +57,11 @@ class BottleParser(core.Parser):
         #  TODO: Make this check more specific
         if core.is_json(req.content_type):
             return core.missing
-        return MultiDictProxy(req.forms, schema)
+        return self._makeproxy(req.forms, schema)
 
     def load_headers(self, req, schema):
         """Return headers from the request as a MultiDictProxy."""
-        return MultiDictProxy(req.headers, schema)
+        return self._makeproxy(req.headers, schema)
 
     def load_cookies(self, req, schema):
         """Return cookies from the request."""
@@ -70,7 +69,7 @@ class BottleParser(core.Parser):
 
     def load_files(self, req, schema):
         """Return files from the request as a MultiDictProxy."""
-        return MultiDictProxy(req.files, schema)
+        return self._makeproxy(req.files, schema)
 
     def handle_error(self, error, req, schema, *, error_status_code, error_headers):
         """Handles errors during parsing. Aborts the current request with a
