@@ -9,7 +9,7 @@ Example usage: ::
     from webargs.pyramidparser import use_args
 
     hello_args = {
-        'name': fields.Str(missing='World')
+        'name': fields.Str(load_default='World')
     }
 
     @use_args(hello_args)
@@ -29,20 +29,20 @@ from __future__ import annotations
 import functools
 from collections.abc import Mapping
 
-from webob.multidict import MultiDict
-from pyramid.httpexceptions import exception_response
-
 import marshmallow as ma
+from pyramid.httpexceptions import exception_response
+from pyramid.request import Request
+from webob.multidict import MultiDict
 
 from webargs import core
 from webargs.core import json
 
 
-def is_json_request(req):
+def is_json_request(req: Request) -> bool:
     return core.is_json(req.headers.get("content-type"))
 
 
-class PyramidParser(core.Parser):
+class PyramidParser(core.Parser[Request]):
     """Pyramid request argument parser."""
 
     DEFAULT_UNKNOWN_BY_LOCATION: dict[str, str | None] = {
@@ -56,7 +56,7 @@ class PyramidParser(core.Parser):
         **core.Parser.__location_map__,
     )
 
-    def _raw_load_json(self, req):
+    def _raw_load_json(self, req: Request):
         """Return a json payload from the request for the core parser's load_json
 
         Checks the input mimetype and may return 'missing' if the mimetype is
@@ -66,32 +66,34 @@ class PyramidParser(core.Parser):
 
         return core.parse_json(req.body, encoding=req.charset)
 
-    def load_querystring(self, req, schema):
+    def load_querystring(self, req: Request, schema):
         """Return query params from the request as a MultiDictProxy."""
         return self._makeproxy(req.GET, schema)
 
-    def load_form(self, req, schema):
+    def load_form(self, req: Request, schema):
         """Return form values from the request as a MultiDictProxy."""
         return self._makeproxy(req.POST, schema)
 
-    def load_cookies(self, req, schema):
+    def load_cookies(self, req: Request, schema):
         """Return cookies from the request as a MultiDictProxy."""
         return self._makeproxy(req.cookies, schema)
 
-    def load_headers(self, req, schema):
+    def load_headers(self, req: Request, schema):
         """Return headers from the request as a MultiDictProxy."""
         return self._makeproxy(req.headers, schema)
 
-    def load_files(self, req, schema):
+    def load_files(self, req: Request, schema):
         """Return files from the request as a MultiDictProxy."""
         files = ((k, v) for k, v in req.POST.items() if hasattr(v, "file"))
         return self._makeproxy(MultiDict(files), schema)
 
-    def load_matchdict(self, req, schema):
+    def load_matchdict(self, req: Request, schema):
         """Return the request's ``matchdict`` as a MultiDictProxy."""
         return self._makeproxy(req.matchdict, schema)
 
-    def handle_error(self, error, req, schema, *, error_status_code, error_headers):
+    def handle_error(
+        self, error, req: Request, schema, *, error_status_code, error_headers
+    ):
         """Handles errors during parsing. Aborts the current HTTP request and
         responds with a 400 error.
         """
@@ -106,7 +108,7 @@ class PyramidParser(core.Parser):
         response.body = body.encode("utf-8") if isinstance(body, str) else body
         raise response
 
-    def _handle_invalid_json_error(self, error, req, *args, **kwargs):
+    def _handle_invalid_json_error(self, error, req: Request, *args, **kwargs):
         messages = {"json": ["Invalid JSON body."]}
         response = exception_response(
             400, detail=str(messages), content_type="application/json"
@@ -118,11 +120,12 @@ class PyramidParser(core.Parser):
     def use_args(
         self,
         argmap,
-        req=None,
+        req: Request | None = None,
         *,
         location=core.Parser.DEFAULT_LOCATION,
         unknown=None,
         as_kwargs=False,
+        arg_name=None,
         validate=None,
         error_status_code=None,
         error_headers=None,
@@ -139,6 +142,8 @@ class PyramidParser(core.Parser):
         :param str unknown: A value to pass for ``unknown`` when calling the
             schema's ``load`` method.
         :param bool as_kwargs: Whether to insert arguments as keyword arguments.
+        :param str arg_name: Keyword argument name to use for arguments. Mutually
+            exclusive with as_kwargs.
         :param callable validate: Validation function that receives the dictionary
             of parsed arguments. If the function returns ``False``, the parser
             will raise a :exc:`ValidationError`.
@@ -148,9 +153,17 @@ class PyramidParser(core.Parser):
             a `ValidationError` is raised.
         """
         location = location or self.location
+
+        if arg_name is not None and as_kwargs:
+            raise ValueError("arg_name and as_kwargs are mutually exclusive")
+        if arg_name is None and not self.USE_ARGS_POSITIONAL:
+            arg_name = f"{location}_args"
+
         # Optimization: If argmap is passed as a dictionary, we only need
         # to generate a Schema once
         if isinstance(argmap, Mapping):
+            if not isinstance(argmap, dict):
+                argmap = dict(argmap)
             argmap = self.schema_class.from_dict(argmap)()
 
         def decorator(func):
@@ -172,7 +185,7 @@ class PyramidParser(core.Parser):
                     error_headers=error_headers,
                 )
                 args, kwargs = self._update_args_kwargs(
-                    args, kwargs, parsed_args, as_kwargs
+                    args, kwargs, parsed_args, as_kwargs, arg_name
                 )
                 return func(obj, *args, **kwargs)
 
